graph.legend.ncol<-: Set the legend number of columns of a SpatialNetwork object
Description
This generic method intends to set or replace the legend number of columns of a SpatialNetwork object.
Usage
graph.legend.ncol(object) <- value
Arguments
object
a SpatialNetwork object.